@@ -1,7 +1,7 @@
 package Alien::TinyCC;
 
 # Follow Golden's Version Rule: http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
-our $VERSION = "0.02_02";
+our $VERSION = "0.02_03";
 $VERSION = eval $VERSION;
 
 use File::ShareDir;
@@ -237,7 +237,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Alien::TinyCC
 
-
 You can also look for information at:
 
 =over 4
@@ -259,6 +258,10 @@ L<http://cpanratings.perl.org/d/Alien-TinyCC>
 L<http://p3rl.org/Alien::TinyCC>
 L<http://search.cpan.org/dist/Alien-TinyCC/>
 
+=item * Stack Overflow
+
+L<//http://stackoverflow.com/questions/tagged/tcc>
+
 =back
 
 =head1 ACKNOWLEDGEMENTS
